@@ -51,22 +51,19 @@ python_info <- function(python) {
       file.exists(file.path(path, "Scripts/activate")) ||
       file.exists(file.path(path, "Scripts/activate.bat"))
 
-    if (virtualenv) {
-      suffix <- if (is_windows()) "Scripts/python.exe" else "bin/python"
-      python <- file.path(path, suffix)
-      return(list(python = python, type = "virtualenv", root = path))
-    }
+    if (is_windows())
+      virtualenv <- virtualenv && (!file.exists("condabin/conda"))
+    
+    if (virtualenv)
+      return(python_info_virtualenv(path))
 
     # check for conda-meta
     condaenv <-
       file.exists(file.path(path, "conda-meta")) &&
       !file.exists(file.path(path, "condabin"))
 
-    if (condaenv) {
-      suffix <- if (is_windows()) "python.exe" else "bin/python"
-      python <- file.path(path, suffix)
-      return(list(python = python, type = "conda", root = path))
-    }
+    if (condaenv)
+      return(python_info_condaenv(path))
     
     # recurse
     parent <- path
@@ -78,3 +75,64 @@ python_info <- function(python) {
   
 }
 
+python_info_virtualenv <- function(path) {
+  
+  # form path to python binary
+  suffix <- if (is_windows()) "Scripts/python.exe" else "bin/python"
+  python <- file.path(path, suffix)
+  
+  # return details
+  list(
+    python = python,
+    type = "virtualenv",
+    root = path
+  )
+  
+}
+
+python_info_condaenv <- function(path) {
+  
+  # form path to python binary
+  suffix <- if (is_windows()) "python.exe" else "bin/python"
+  python <- file.path(path, suffix)
+  
+  # find path to conda associated with this env
+  conda <- python_info_condaenv_find(path)
+  
+  list(
+    python = python,
+    type   = "conda",
+    root   = path,
+    conda  = conda
+  )
+  
+}
+
+python_info_condaenv_find <- function(path) {
+  
+  # read history file
+  histpath <- file.path(path, "conda-meta/history")
+  if (!file.exists(histpath))
+    return(NULL)
+  
+  history <- readLines(histpath, warn = FALSE)
+  
+  # look for cmd line
+  pattern <- "^[[:space:]]*#[[:space:]]*cmd:[[:space:]]*"
+  lines <- grep(pattern, history, value = TRUE)
+  if (length(lines) == 0)
+    return(NULL)
+  
+  # get path to conda script used
+  line <- gsub(pattern, "", lines[[1]])
+  parts <- strsplit(line, "[[:space:]]+")[[1]]
+  script <- parts[[1]]
+  
+  # on Windows, a wrapper script is recorded in the history,
+  # so instead attempt to find the real conda binary
+  exe <- if (is_windows()) "conda.exe" else "conda"
+  conda <- file.path(dirname(script), exe)
+  
+  normalizePath(conda, winslash = "/", mustWork = FALSE)
+  
+}
