@@ -56,14 +56,9 @@ repl_python <- function(
   }
 
   # import other required modules for the REPL
-  builtins <- import_builtins(convert = FALSE)
   sys <- import("sys", convert = TRUE)
   codeop <- import("codeop", convert = TRUE)
 
-  # grab references to the locals, globals of the main module
-  locals <- py_run_string("locals()")
-  globals <- py_run_string("globals()")
-
   # check to see if the current environment supports history
   # (check for case where working directory not writable)
   use_history <-
@@ -122,36 +117,18 @@ repl_python <- function(
     failed
   }
 
-  # submit code for evaluation. return TRUE if evaluation succeeded
-  process <- function(code) {
-
-    # Python's command compiler complains if the only thing you submit
-    # is a comment, so detect that case first
-    if (grepl("^\\s*#", code))
-      return(TRUE)
-
-    # Python is picky about trailing whitespace, so ensure only a single
-    # newline follows the code to be submitted
-    code <- sub("\\s*$", "\n", code)
-
-    # now compile and run the code. we use 'single' mode to ensure that
-    # python auto-prints the statement as it is evaluated.
-    compiled <- tryCatch(builtins$compile(code, '<string>', 'single'), error = identity)
-    if (handle_error(compiled))
-      return(FALSE)
-
-    output <- tryCatch(builtins$eval(compiled, globals, locals), error = identity)
-    if (handle_error(output))
-      return(FALSE)
-
-    # ensure stdout, stderr flushed (required for Python 3)
-    sys$stdout$flush()
-    sys$stderr$flush()
-
-    TRUE
-  }
-
   repl <- function() {
+    
+    # flush stdout, stderr on each REPL iteration
+    on.exit({
+      
+      if (!is.null(sys$stdout) && !is.null(sys$stdout$flush))
+        sys$stdout$flush()
+      
+      if (!is.null(sys$stderr) && !is.null(sys$stderr$flush))
+        sys$stderr$flush()
+      
+    }, add = TRUE)
 
     # read user input
     prompt <- if (buffer$empty()) ">>> " else "... "
@@ -218,10 +195,12 @@ repl_python <- function(
     }
 
     # update history file
-    if (use_history) {
-      write(contents, file = histfile, append = TRUE)
-      utils::loadhistory(histfile)
-    }
+    if (use_history)
+      cat(contents, file = histfile, sep = "\n", append = TRUE)
+
+    # trim whitespace if the buffer is empty (this effectively allows leading
+    # whitespace in top-level Python commands)
+    if (buffer$empty()) contents <- trimmed
 
     # update buffer
     previous <- buffer$data()
@@ -253,7 +232,8 @@ repl_python <- function(
     if (length(previous) && inherits(ready, "error")) {
 
       # submit previous code
-      process(paste(previous, collapse = "\n"))
+      pasted <- paste(previous, collapse = "\n")
+      tryCatch(py_compile_eval(pasted, capture = FALSE), error = handle_error)
 
       # now, handle the newest line of code submitted
       buffer$set(contents)
@@ -268,7 +248,7 @@ repl_python <- function(
     # otherwise, we should have received a code output object
     # so we can just run the code submitted thus far
     buffer$clear()
-    process(code)
+    tryCatch(py_compile_eval(code, capture = FALSE), error = handle_error)
 
   }
 
@@ -282,7 +262,10 @@ repl_python <- function(
       sep = "."
     )
 
-    executable <- sys$executable
+    # NOTE: we used to use sys.executable but that would report
+    # the R process rather than the Python process
+    config <- py_config()
+    executable <- config$python
 
     fmt <- c(
       "Python %s (%s)",
@@ -319,4 +302,3 @@ repl_python <- function(
 py_repl_active <- function() {
   .globals$py_repl_active
 }
-
