@@ -2,7 +2,7 @@ context("delay-load")
 
 library(callr)
 
-test_that("imoprted module can be customized via delay_load", {
+test_that("imported module can be customized via delay_load", {
   skip_if_no_python()
   skip_on_travis()
   expect_true(r(function() {
@@ -15,3 +15,4 @@ test_that("imoprted module can be customized via delay_load", {
   }))
 })
 
+
