@@ -6,7 +6,7 @@ test_that("An R Markdown document can be rendered using reticulate", {
   skip_if_no_python()
   skip_if_not_installed("rmarkdown")
 
-  modules <- c("numpy", "matplotlib")
+  modules <- c("numpy", "matplotlib", "pandas")
   for (module in modules) {
     if (!py_module_available(module)) {
       fmt <- "module '%s' not available; skipping"
